TOPSIS-Python
Submitted By: Vishal Gulati 101803152

pypi: https://pypi.org/project/TOPSIS-Vishal-101803152/

What is TOPSIS
Technique for Order Preference by Similarity to Ideal Solution (TOPSIS) originated in the 1980s as a multi-criteria decision making method. TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution, and greatest distance from the negative-ideal solution. More details at wikipedia.


How to use this package:
TOPSIS-Vishal-101803152 can be run as in the following example:

In Command Prompt
>> pip install TOPSIS-Vishal-101803152==0.4
python

from topsis_gen.topsis_cal import topsis topsis("data.csv","1,1,1,2","+,+,-,+")


